@@ -32,6 +32,8 @@ protected:
 	int	Decoding(unsigned char bitval);
 	int	ReadDataOne(int Idx, unsigned char * Genotype);
 	int	GetStartByte(int SNP_Idx);
+	int ReadFile(int start);
+	int SeekG(int start);
 	
 private:
 	
@@ -41,10 +43,14 @@ private:
 	int		m_nSample;
 	int		m_nSNP;
 	int		m_BlockSize;
+	int		m_FileSize;
 
 	unsigned char	m_decode_out[4];
 	unsigned char 	m_magic_number[3];
 	unsigned char	*m_pbuffer;	
+	
+	int m_debugPos ;
+	int m_debuglength ;
 
 
 };
